@@ -17,18 +17,23 @@ bagControl <- function(fit = NULL, predict = NULL, aggregate = NULL, downSample
   
 
 "bag.default" <-
-  function(x, y, B = 10, vars = ncol(x), bagControl = bagControl(),  ...)
+  function(x, y, B = 10, vars = ncol(x), bagControl = NULL,  ...)
 {
   funcCall <- match.call(expand.dots = TRUE)
 
+  if(is.null(bagControl)) stop("Please specify 'bagControl' with the appropriate functions")
+    
    if(!is.null(vars) && vars < 1) stop("vars must be an integer > 0")
 
-  if(bagControl$downSample & is.numeric(y))
-    {
+  if(bagControl$downSample & is.numeric(y)) {
       warning("down-sampling with regression... downSample changed to FALSE")
       bagControl$downSample <- FALSE
     }
-
+  
+  if(is.null(bagControl$fit) | is.null(bagControl$predict) | 
+       is.null(bagControl$aggregate)) {
+    stop("The control arguments 'fit', 'predict' and 'aggregate' should have non-NULL values")
+  }
 
   fitter <- function(index, x, y, ctrl, v, ...)
     {
@@ -58,8 +63,7 @@ bagControl <- function(fit = NULL, predict = NULL, aggregate = NULL, downSample
       fit <- ctrl$fit(subX, subY, ...)
       if(ctrl$oob)
         {
-          pred <- ctrl$pred(fit,
-                            x[-unique(index), subVars, drop = FALSE])
+          pred <- ctrl$predict(fit, x[-unique(index), subVars, drop = FALSE])
           if(is.vector(pred))
             {
               out <- data.frame(pred  = pred, obs = y[-unique(index)])
